
Keras DropBlock
===============


.. image:: https://travis-ci.org/CyberZHG/keras-drop-block.svg
   :target: https://travis-ci.org/CyberZHG/keras-drop-block
   :alt: Travis


.. image:: https://coveralls.io/repos/github/CyberZHG/keras-drop-block/badge.svg?branch=master
   :target: https://coveralls.io/github/CyberZHG/keras-drop-block
   :alt: Coverage


Implementation of `DropBlock <https://arxiv.org/pdf/1810.12890.pdf>`_

Install
-------

.. code-block:: bash

   pip install keras-drop-block

Usage
-----

See `fashion mnist demo <./demo/mnist.py>`_.
